changeset 54210:602769168263

Replace "As Is..." in PostScript file print/preview by "No Preprocessing...".
author Vinicius Jose Latorre <viniciusjl@ig.com.br>
date Mon, 01 Mar 2004 02:26:01 +0000
parents c312c950b64d
children f8a2c975db26
files lisp/ChangeLog lisp/printing.el
diffstat 2 files changed, 18 insertions(+), 16 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Sun Feb 29 23:59:04 2004 +0000
+++ b/lisp/ChangeLog	Mon Mar 01 02:26:01 2004 +0000
@@ -15,7 +15,10 @@
 
 2004-02-29  Vinicius Jose Latorre  <viniciusjl@ig.com.br>
 
-	* printing.el (pr-insert-section-4): Adjust buffer interface.
+	* printing.el: Replace "As Is..." in PostScript file print/preview by
+	"No Preprocessing...".  Suggested by Colin Marquardt
+	<marquardt@zmd.de>.
+	(pr-insert-section-4): Adjust buffer interface.
 
 2004-02-29  Kai Grossjohann  <kai.grossjohann@gmx.net>
 
--- a/lisp/printing.el	Sun Feb 29 23:59:04 2004 +0000
+++ b/lisp/printing.el	Mon Mar 01 02:26:01 2004 +0000
@@ -5,7 +5,7 @@
 
 ;; Author: Vinicius Jose Latorre <vinicius@cpqd.com.br>
 ;; Maintainer: Vinicius Jose Latorre <vinicius@cpqd.com.br>
-;; Time-stamp: <2004/02/29 20:52:58 vinicius>
+;; Time-stamp: <2004/02/29 23:18:15 vinicius>
 ;; Keywords: wp, print, PostScript
 ;; Version: 6.7.2
 ;; X-URL: http://www.cpqd.com.br/~vinicius/emacs/
@@ -517,7 +517,7 @@
 ;;     5  |   Print                    >|---\ | |Despool... |  |
 ;;     6  |   Text Printer: name       >|-\ | | +-----------+  |
 ;;        +-----------------------------+ | | | +---------+   +------------+
 ;; III 7  |[ ]Landscape                 | | | \-|Directory|   |   As Is... | Ia
 ;;     8  |[ ]Print Header              | | |   |Buffer   |   +------------+ Ib
 ;;     9  |[ ]Print Header Frame        | | |   |Region   |   |   name    >|- C
 ;;     10 |[ ]Line Number               | | |   +---------+   +------------+
@@ -581,8 +581,8 @@
 ;;
 ;;	 NOTE 2: There are the following options for PostScript file
 ;;		 processing:
 ;;		 Ia. Print the file *as is*, that is, send it directly to
 ;;		     PostScript printer.
 ;;		 Ib. PostScript utility processing selection.
 ;;		     See `pr-ps-utility-alist' and `pr-setting-database' for
 ;;		     documentation.
@@ -2415,7 +2415,7 @@
 	  ["Other..." (pr-ps-mode-preview nil t)
 	   :keys "\\[pr-ps-mode-preview]"])
 	 ("File"
-	  ["As Is..."  (call-interactively 'pr-ps-file-preview)
+	  ["No Preprocessing..." (call-interactively 'pr-ps-file-preview)
 	   :keys "\\[pr-ps-file-preview]"
 	   :help "Preview PostScript file"]
 	  "--"
@@ -2470,7 +2470,7 @@
 	  ["Other..." (pr-ps-mode-ps-print nil t)
 	   :keys "\\[pr-ps-mode-ps-print]"])
 	 ("File"
-	  ["As Is..."  (call-interactively 'pr-ps-file-ps-print)
+	  ["No Preprocessing..." (call-interactively 'pr-ps-file-ps-print)
 	   :keys "\\[pr-ps-file-ps-print]"
 	   :help "Send PostScript file to printer"]
 	  "--"
@@ -2624,7 +2624,7 @@
 	  ["Other..." (pr-ps-mode-preview nil t)
 	   :keys "\\[pr-ps-mode-preview]"])
 	 ("File"
-	  ["As Is..."  (call-interactively 'pr-ps-file-preview)
+	  ["No Preprocessing..." (call-interactively 'pr-ps-file-preview)
 	   :keys "\\[pr-ps-file-preview]"]
 	  "--"
 	  ["PostScript Utility" pr-update-menus :active pr-ps-utility-alist]
@@ -2672,7 +2672,7 @@
 	  ["Other..." (pr-ps-mode-ps-print nil t)
 	   :keys "\\[pr-ps-mode-ps-print]"])
 	 ("File"
-	  ["As Is..."  (call-interactively 'pr-ps-file-ps-print)
+	  ["No Preprocessing..." (call-interactively 'pr-ps-file-ps-print)
 	   :keys "\\[pr-ps-file-ps-print]"]
 	  "--"
 	  ["PostScript Utility" pr-update-menus :active pr-ps-utility-alist]
@@ -2861,7 +2861,7 @@
     5  |   Print                    >|---\\ | |Despool... |  |
     6  |   Text Printer: name       >|-\\ | | +-----------+  |
        +-----------------------------+ | | | +---------+   +------------+
-III 7  |[ ]Landscape                 | | | \\-|Directory|   |   As Is... | Ia
+III 7  |[ ]Landscape                 | | | \\-|Directory|   | No Prep... | Ia
     8  |[ ]Print Header              | | |   |Buffer   |   +------------+ Ib
     9  |[ ]Print Header Frame        | | |   |Region   |   |   name    >|- C
     10 |[ ]Line Number               | | |   +---------+   +------------+
@@ -2923,8 +2923,8 @@
 	      switch from gnus *Summary* buffer first.
 
       NOTE 2: There are the following options for PostScript file processing:
-	      Ia. Print the file *as is*, that is, send it directly to
-		  PostScript printer.
+	      Ia. Print the file *No Preprocessing*, that is, send it
+		  directly to PostScript printer.
 	      Ib. PostScript utility processing selection.
 		  See `pr-ps-utility-alist' and `pr-setting-database' for
 		  documentation.
@@ -3130,7 +3130,7 @@
       NOTE 2: Don't forget to download and install the utilities declared on
 	      `pr-ps-utility-alist'.
 
-      * Use It AS-IS :
+      * No Preprocessing:
 	 If it's turned on, don't use the PostScript utility to preprocess the
 	 PostScript file before printing/previewing.
 
@@ -5752,9 +5752,8 @@
 		  (pr-choice-alist pr-ps-utility-alist)
 		  "\n      PostScript Utility : "
 		  "    ")
-  ;;    1c. PostScript File: Use It AS-IS
-  (pr-insert-toggle 'pr-i-ps-as-is " Use It ")
-  (pr-insert-italic "AS-IS"))
+  ;;    1c. PostScript File: No Preprocessing
+  (pr-insert-toggle 'pr-i-ps-as-is " No Preprocessing"))
 
 
 (defun pr-insert-section-2 ()
@@ -517,7 +517,7 @@
 ;;     6  |   Text Printer: name       >|-\ | | +-----------+  |
 ;;        +-----------------------------+ | | | +---------+   +------------+
-;; III 7  |[ ]Landscape                 | | | \-|Directory|   |   As Is... | Ia
+;; III 7  |[ ]Landscape                 | | | \-|Directory|   | No Prep... | Ia
 ;;     8  |[ ]Print Header              | | |   |Buffer   |   +------------+ Ib
 ;;     9  |[ ]Print Header Frame        | | |   |Region   |   |   name    >|- C
@@ -581,8 +581,8 @@
 ;;	 NOTE 2: There are the following options for PostScript file
 ;;		 processing:
-;;		 Ia. Print the file *as is*, that is, send it directly to
-;;		     PostScript printer.
+;;		 Ia. Print the file *No Preprocessing*, that is, send it
+;;		     directly to PostScript printer.
 ;;		 Ib. PostScript utility processing selection.
 ;;		     See `pr-ps-utility-alist' and `pr-setting-database' for